@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2019-2022 -- leonerd@leonerd.org.uk
 
-package Object::Pad 0.60;
+package Object::Pad 0.62;
 
 use v5.14;
 use warnings;
@@ -420,7 +420,7 @@ the role.
 
    has $var = EXPR;
 
-   has $var { BLOCK };
+   has $var { BLOCK }
 
 Declares that the instances of the class or role have a member field of the
 given name. This member field will be accessible as a lexical variable within
@@ -609,12 +609,19 @@ are invoked.
       ...
    }
 
+   method NAME;
+
 Declares a new named method. This behaves similarly to the C<sub> keyword,
 except that within the body of the method all of the member fields are also
 accessible. In addition, the method body will have a lexical called C<$self>
 which contains the invocant object directly; it will already have been shifted
 from the C<@_> array.
 
+If the method has no body and is given simply as a name, this declares a
+I<required> method for a role. Such a method must be provided by any class
+that implements the role. It will be a compiletime error to combine the role
+with a class that does not provide this.
+
 The C<signatures> feature is automatically enabled for method declarations. In
 this case the signature does not have to account for the invocant instance; 
 that is handled directly.
@@ -653,6 +660,16 @@ Marks that this method expects to override another of the same name from a
 superclass. It is an error at compiletime if the superclass does not provide
 such a method.
 
+=head3 :common
+
+I<Since version 0.62.>
+
+Marks that this method is a class-common method, instead of a regular instance
+method. A class-common method may be invoked on class names instead of
+instances. Within the method body there is a lexical C<$class> available,
+rather than C<$self>. Because it is not associated with a particular object
+instance, a class-common method cannot see instance fields.
+
 =head2 method (lexical)
 
    method $var { ... }
@@ -767,6 +784,9 @@ Declares that this role requires a method of the given name from any class
 that implements it. It is an error at compiletime if the implementing class
 does not provide such a method.
 
+This form of declaring a required method is now vaguely discouraged, in favour
+of the bodyless C<method> form described above.
+
 =head1 CREPT FEATURES
 
 While not strictly part of being an object system, this module has
