@@ -18,6 +18,7 @@
 #include "force_list_keeping_pushmark.c.inc"
 #include "optree-additions.c.inc"
 #include "newOP_CUSTOM.c.inc"
+#include "cv_copy_flags.c.inc"
 
 #ifdef DEBUGGING
 #  define DEBUG_OVERRIDE_PLCURCOP
@@ -27,6 +28,24 @@
 #  define DEBUG_SET_CURCOP_LINE(line)
 #endif
 
+#define need_PLparser()  S_need_PLparser(aTHX)
+static void S_need_PLparser(pTHX)
+{
+  if(!PL_parser) {
+    /* We need to generate just enough of a PL_parser to keep newSTATEOP()
+     * happy, otherwise it will SIGSEGV (RT133258)
+     */
+    SAVEVPTR(PL_parser);
+    Newxz(PL_parser, 1, yy_parser);
+    SAVEFREEPV(PL_parser);
+
+    PL_parser->copline = NOLINE;
+#if HAVE_PERL_VERSION(5, 20, 0)
+    PL_parser->preambling = NOLINE;
+#endif
+  }
+}
+
 /* Empty MGVTBL simply for locating instance backing AV */
 static MGVTBL vtbl_backingav = {};
 
@@ -267,7 +286,10 @@ static CV *S_embed_cv(pTHX_ CV *cv, RoleEmbedding *embedding)
   assert(cv);
   assert(CvOUTSIDE(cv));
 
-  CV *embedded_cv = cv_clone(cv);
+  /* Perl core's cv_clone() would break in some situation here; see
+   *   https://rt.cpan.org/Ticket/Display.html?id=141483
+   */
+  CV *embedded_cv = cv_copy_flags(cv, 0);
   SV *embeddingsv = embedding->embeddingsv;
 
   assert(SvTYPE(embeddingsv) == SVt_PV && SvLEN(embeddingsv) >= sizeof(RoleEmbedding));
@@ -417,6 +439,16 @@ void ObjectPad_mop_class_add_ADJUSTPARAMS(pTHX_ ClassMeta *meta, CV *cv)
   av_push(meta->adjustblocks, (SV *)block);
 }
 
+void ObjectPad_mop_class_add_required_method(pTHX_ ClassMeta *meta, SV *methodname)
+{
+  if(meta->type != METATYPE_ROLE)
+    croak("Can only add a required method to a role");
+  if(meta->sealed)
+    croak("Cannot add a new required method to an already-sealed class");
+
+  av_push(meta->requiremethods, SvREFCNT_inc(methodname));
+}
+
 #define mop_class_implements_role(meta, rolemeta)  S_mop_class_implements_role(aTHX_ meta, rolemeta)
 static bool S_mop_class_implements_role(pTHX_ ClassMeta *meta, ClassMeta *rolemeta)
 {
@@ -514,6 +546,7 @@ static RoleEmbedding *S_embed_role(pTHX_ ClassMeta *classmeta, ClassMeta *roleme
     {
       MethodMeta *dstmethodmeta = mop_class_add_method(classmeta, mname);
       dstmethodmeta->role = rolemeta;
+      dstmethodmeta->is_common = methodmeta->is_common;
     }
 
     GV **gvp = (GV **)hv_fetch(dststash, SvPVX(mname), SvCUR(mname), GV_ADD);
@@ -740,6 +773,8 @@ static void S_generate_initfields_method(pTHX_ ClassMeta *meta)
 
   ENTER;
 
+  need_PLparser();
+
   I32 floor_ix = PL_savestack_ix;
   {
     SAVEI32(PL_subline);
@@ -1525,19 +1560,7 @@ ClassMeta *ObjectPad_mop_create_class(pTHX_ enum MetaType type, SV *name)
       break;
   }
 
-  if(!PL_parser) {
-    /* We need to generate just enough of a PL_parser to keep newSTATEOP()
-     * happy, otherwise it will SIGSEGV (RT133258)
-     */
-    SAVEVPTR(PL_parser);
-    Newxz(PL_parser, 1, yy_parser);
-    SAVEFREEPV(PL_parser);
-
-    PL_parser->copline = NOLINE;
-#if HAVE_PERL_VERSION(5, 20, 0)
-    PL_parser->preambling = NOLINE;
-#endif
-  }
+  need_PLparser();
 
   /* Prepare meta->initfields for containing a CV parsing operation */
   {
